==> bucketlib-fabric-1.21.3-4.2.0.7-sources.jar: de/cech12/bucketlib/platform/FabricRegistryHelper.java <==
package de.cech12.bucketlib.platform;

import de.cech12.bucketlib.BucketLibMod;
import de.cech12.bucketlib.api.item.UniversalBucketItem;
import de.cech12.bucketlib.platform.services.IRegistryHelper;
import java.util.List;
import java.util.Objects;
import net.minecraft.class_1299;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3611;
import net.minecraft.class_6880;
import net.minecraft.class_7923;

/**
 * The registry service implementation for NeoForge.
 */
public class FabricRegistryHelper implements IRegistryHelper {
    @Override
    public List<UniversalBucketItem> getRegisteredBuckets() {
        return BucketLibMod.getRegisteredBuckets();
    }

    @Override
    public class_1299<?> getEntityType(class_2960 location) {
        return class_7923.field_41177.method_10223(location).map(class_6880.class_6883::comp_349).orElse(null);
    }

    @Override
    public class_2960 getEntityTypeLocation(class_1299<?> entityType) {
        return Objects.requireNonNull(class_7923.field_41177.method_10221(entityType));
    }

    @Override
    public class_2248 getBlock(class_2960 location) {
        return class_7923.field_41175.method_10223(location).map(class_6880.class_6883::comp_349).orElse(null);
    }

    @Override
    public class_2960 getBlockLocation(class_2248 block) {
        return class_7923.field_41175.method_10221(block);
    }

    @Override
    public Iterable<class_1792> getAllItems() {
        return class_7923.field_41178;
    }

    @Override
    public Iterable<class_3611> getAllFluids() {
        return class_7923.field_41173;
    }

    @Override
    public class_3611 getFluid(class_2960 location) {
        return class_7923.field_41173.method_10223(location).map(class_6880.class_6883::comp_349).orElse(null);
    }

    @Override
    public class_2960 getFluidLocation(class_3611 fluid) {
        return class_7923.field_41173.method_10221(fluid);
    }
}

==> bucketlib-fabric-1.21-4.1.6.0-sources.jar: de/cech12/bucketlib/platform/FabricRegistryHelper.java <==
package de.cech12.bucketlib.platform;

import de.cech12.bucketlib.BucketLibMod;
import de.cech12.bucketlib.api.item.UniversalBucketItem;
import de.cech12.bucketlib.platform.services.IRegistryHelper;
import java.util.List;
import java.util.Objects;
import net.minecraft.class_1299;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3611;
import net.minecraft.class_7923;

/**
 * The registry service implementation for NeoForge.
 */
public class FabricRegistryHelper implements IRegistryHelper {
    @Override
    public List<UniversalBucketItem> getRegisteredBuckets() {
        return BucketLibMod.getRegisteredBuckets();
    }

    @Override
    public class_1299<?> getEntityType(class_2960 location) {
        return class_7923.field_41177.method_10223(location);
    }

    @Override
    public class_2960 getEntityTypeLocation(class_1299<?> entityType) {
        return Objects.requireNonNull(class_7923.field_41177.method_10221(entityType));
    }

    @Override
    public class_2248 getBlock(class_2960 location) {
        return class_7923.field_41175.method_10223(location);
    }

    @Override
    public class_2960 getBlockLocation(class_2248 block) {
        return class_7923.field_41175.method_10221(block);
    }

    @Override
    public Iterable<class_1792> getAllItems() {
        return class_7923.field_41178;
    }

    @Override
    public Iterable<class_3611> getAllFluids() {
        return class_7923.field_41173;
    }

    @Override
    public class_3611 getFluid(class_2960 location) {
        return class_7923.field_41173.method_10223(location);
    }

    @Override
    public class_2960 getFluidLocation(class_3611 fluid) {
        return class_7923.field_41173.method_10221(fluid);
    }
}
